@@ -419,7 +419,7 @@ class SlashCommand():
         if default_permission is MISSING:
             default_permission = True
         self.default_permission: bool = default_permission
-        if guild_permissions is not MISSING:
+        if guild_permissions not in [MISSING, None]:
             for _id, perm in list(guild_permissions.items()):
                 if type(_id) not in [str, int, discord.User, discord.Member, discord.Role]:
                     raise WrongType("guild_permissions key " + str(_id), _id, ["str", "int", "discord.User", "discord.Member", "discord.Role"])
@@ -544,12 +544,12 @@ class SlashSubcommand(SlashCommand):
 
 
 class ContextCommand(SlashCommand):
-    def __init__(self, callback, name, guild_ids, default_permission = True, guild_permissions = MISSING) -> None:
+    def __init__(self, callback, name=MISSING, guild_ids=MISSING, default_permission = True, guild_permissions = MISSING) -> None:
         if callback is not None:
             callback_params = inspect.signature(callback).parameters
             if len(callback_params) < 2:
                 raise CallbackMissingContextCommandParameters()
-        super().__init__(callback, name, guild_ids=guild_ids, default_permission=default_permission, guild_permissions=guild_permissions)
+        super().__init__(callback, name=name, guild_ids=guild_ids, default_permission=default_permission, guild_permissions=guild_permissions)
 
     @property
     def description(self) -> str:
@@ -565,11 +565,11 @@ class ContextCommand(SlashCommand):
         pass
         
 class UserCommand(ContextCommand):
-    def __init__(self, callback, name, guild_ids = MISSING, default_permission = True, guild_permissions = MISSING) -> None:
+    def __init__(self, callback, name=MISSING, guild_ids = MISSING, default_permission = True, guild_permissions = MISSING) -> None:
         super().__init__(callback, name, guild_ids, default_permission, guild_permissions)
         self._json["type"] = CommandType.USER
 
 class MessageCommand(ContextCommand):
-    def __init__(self, callback, name, guild_ids = MISSING, default_permission = True, guild_permissions = MISSING) -> None:
+    def __init__(self, callback, name=MISSING, guild_ids = MISSING, default_permission = True, guild_permissions = MISSING) -> None:
         super().__init__(callback, name, guild_ids, default_permission, guild_permissions)
         self._json["type"] = CommandType.MESSAGE
\ No newline at end of file
